@@ -1,5 +1,5 @@
-/* 
- * This is taken from linux kernel source.
+/*
+ * This is taken from Linux kernel source.
  */
 
 /*
@@ -16,7 +16,7 @@ struct list_head {
 	struct list_head *next, *prev;
 };
 
-#define LIST_HEAD(name) \
+#define DECL_LIST_HEAD(name) \
 	struct list_head name = { &name, &name }
 
 #define INIT_LIST_HEAD(ptr) do { \
@@ -24,7 +24,7 @@ struct list_head {
 } while (0)
 
 /*
- * Insert a new entry between two known consecutive entries. 
+ * Insert a new entry between two known consecutive entries.
  *
  * This is only for internal list manipulation where we know
  * the prev/next entries already!
